@@ -32,22 +32,24 @@ class Table(object):
             return False
         return True
 
-    def __init__(self, index=None, data_file=None, table_name=None, metadata=None, data=[]):
-        self.data = data
+    def __init__(self, index=None, data_file=None, table_name=None, metadata=None, data=None):
+        self.data = data or []
         self.index = index
         self.qualifiers = []
+        self.dserrors = []
 
         self.metadata = metadata or {
             'name': table_name or 'Table %s' % self.index,
-            'location': None,
-            'description': None,
+            'location': '',
+            'description': '',
             'keywords': [
                 {'name': 'reactions', 'values': []},
                 {'name': 'observables', 'values': []},
-                {'name': 'energies', 'values': []},
+                {'name': 'phrases', 'values': []},
+                {'name': 'cmenergies', 'values': []},
             ],
             'data_file': data_file or 'data%s.yaml' % index,
-            # it seams it's required
+            # it seems it's required
             # TODO - is it really required? should sensible defaults be provided?
             'data_license': {
                 'name': None,
@@ -76,7 +78,9 @@ class Table(object):
                 self.reactions = keyword['values']
             elif keyword['name'] == 'observables':
                 self.observables = keyword['values']
-            elif keyword['name'] == 'energies':
+            elif keyword['name'] == 'phrases':
+                self.phrases = keyword['values']
+            elif keyword['name'] == 'cmenergies':
                 self.energies = keyword['values']
 
         self.data_file = self.metadata['data_file']
