@@ -1,13 +1,10 @@
 # -*- encoding: utf-8 -*-
-import os
 import hepdata_converter
 from hepdata_converter.testsuite import insert_path, insert_data_as_str
 from hepdata_converter.testsuite.test_writer import WriterTestSuite
 
 __author__ = 'Michał Szostak'
 
-import unittest
-
 
 class YAMLWriterTestSuite(WriterTestSuite):
     @insert_path('yaml_qual')
@@ -18,5 +15,3 @@ class YAMLWriterTestSuite(WriterTestSuite):
                                                              'single_file': True})
 
         self.assertEqual(data, table_5_noqual)
-
-
