@@ -3,6 +3,10 @@ from hepdata_converter.common import Option, OptionInitMixin
 from hepdata_converter.writers import Writer
 import os
 
+def str_presenter(dumper, data):
+    if '\n' in data in data:
+        return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='|')
+    return dumper.represent_scalar('tag:yaml.org,2002:str', data)
 
 class YAML(Writer):
     help = 'Writes YAML output. Output should be defined as filepath to the directory where submission.yaml and associated ' \
@@ -18,6 +22,7 @@ class YAML(Writer):
 
     def __init__(self, *args, **kwargs):
         super(YAML, self).__init__(single_file_output=True, *args, **kwargs)
+        yaml.add_representer(str, str_presenter)
 
     def write(self, data_in, data_out, *args, **kwargs):
         """
@@ -33,19 +38,37 @@ class YAML(Writer):
         tables = data_in.tables
         data = data_in.data
 
+        if self.hepdata_doi:
+            data['hepdata_doi'] = self.hepdata_doi
+            for table in tables:
+                table.metadata['table_doi'] = self.hepdata_doi + '/t' + str(table.index)
+
         if not isinstance(data_out, (str, unicode)) and not self.single_file:
             raise ValueError("output is not string, and single_file flag is not specified")
 
         if not self.single_file:
             self.create_dir(data_out)
             with open(os.path.join(data_out, 'submission.yaml'), 'w') as submission_file:
-                yaml.dump_all([data] + [table.metadata for table in tables], submission_file)
+                try:
+                    yaml.dump_all([data] + [table.metadata for table in tables], submission_file, dumper=yaml.CDumper)
+                except:
+                    yaml.dump_all([data] + [table.metadata for table in tables], submission_file)
+
                 for table in tables:
                     with open(os.path.join(data_out, table.data_file), 'w') as table_file:
-                        yaml.dump(table.data, table_file)
+                        try:
+                            yaml.dump(table.data, table_file, dumper=yaml.CDumper)
+                        except:
+                            yaml.dump(table.data, table_file)
         else:
             if isinstance(data_out, (str, unicode)):
                 with open(data_out, 'w') as submission_file:
-                    yaml.dump_all([data] + [table.metadata for table in tables] + [table.all_data for table in tables], submission_file)
+                    try:
+                        yaml.dump_all([data] + [table.all_data for table in tables], submission_file, dumper=yaml.CDumper)
+                    except:
+                        yaml.dump_all([data] + [table.all_data for table in tables], submission_file)
             else: # expect filelike object
-                yaml.dump_all([data] + [table.metadata for table in tables] + [table.all_data for table in tables], data_out)
\ No newline at end of file
+                try:
+                    yaml.dump_all([data] + [table.all_data for table in tables], data_out, dumper=yaml.CDumper)
+                except:
+                    yaml.dump_all([data] + [table.all_data for table in tables], data_out)
\ No newline at end of file
